@@ -1,10 +1,15 @@
 import asyncio
 import random
+from ssl import SSLContext
+from socket import socket
+from typing import Callable, Any, Dict, Optional, Sequence
 
+from mysql_mimic.auth import IdentityProvider, SimpleIdentityProvider
 from mysql_mimic.connection import Connection
 from mysql_mimic.session import Session
 from mysql_mimic.constants import DEFAULT_SERVER_CAPABILITIES
 from mysql_mimic.stream import MysqlStream
+from mysql_mimic.types import Capabilities
 from mysql_mimic.utils import seq
 
 
@@ -17,12 +22,15 @@ class MysqlServer:
     MySQL mimic server.
 
     Args:
-        session_factory (()->Session): Callable that takes no arguments and returns a session
-        capabilities (int): server capability flags
-        server_id (int): set a unique server ID. This is used to generate globally unique
+        session_factory: Callable that takes no arguments and returns a session
+        capabilities: server capability flags
+        server_id: set a unique server ID. This is used to generate globally unique
             connection IDs. This should be an integer between 0 and 65535.
             If left as None, a random server ID will be generated.
-        conn_kwargs (dict): extra keyword args passed to new `Connection` instances
+        identity_provider: Authentication plugins to register. Defaults to `SimpleIdentityProvider`,
+            which just blindly accepts whatever `username` is given by the client.
+        ssl: SSLContext instance if this server should enable TLS over connections
+
         **kwargs: extra keyword args passed to the asyncio start server command
     """
 
@@ -32,29 +40,35 @@ class MysqlServer:
 
     def __init__(
         self,
-        session_factory=Session,
-        capabilities=DEFAULT_SERVER_CAPABILITIES,
-        server_id=None,
-        conn_kwargs=None,
-        **serve_kwargs,
+        session_factory: Callable[[], Session] = Session,
+        capabilities: Capabilities = DEFAULT_SERVER_CAPABILITIES,
+        server_id: int = None,
+        identity_provider: IdentityProvider = None,
+        ssl: SSLContext = None,
+        **serve_kwargs: Any,
     ):
         self.session_factory = session_factory
         self.capabilities = capabilities
         self.server_id = server_id or self._get_server_id()
-        self.conn_kwargs = conn_kwargs
-        self._connection_seq = seq(self._MAX_CONNECTION_SEQ)
-        self._connections = {}
-        self._serve_kwargs = serve_kwargs
-        self._server = None
+        self.identity_provider = identity_provider or SimpleIdentityProvider()
+        self.ssl = ssl
 
-    async def _client_connected_cb(self, reader, writer):
+        self._connection_seq = seq(self._MAX_CONNECTION_SEQ)
+        self._connections: Dict[int, Connection] = {}
+        self._serve_kwargs = serve_kwargs
+        self._server: Optional[asyncio.base_events.Server] = None
+
+    async def _client_connected_cb(
+        self, reader: asyncio.StreamReader, writer: asyncio.StreamWriter
+    ) -> None:
         connection_id = self._get_connection_id()
         connection = Connection(
             stream=MysqlStream(reader, writer),
             session=self.session_factory(),
             server_capabilities=self.capabilities,
             connection_id=connection_id,
-            **(self.conn_kwargs or {}),
+            identity_provider=self.identity_provider,
+            ssl=self.ssl,
         )
         self._connections[connection_id] = connection
         try:
@@ -62,10 +76,10 @@ class MysqlServer:
         finally:
             self._connections.pop(connection_id, None)
 
-    def _get_server_id(self):
+    def _get_server_id(self) -> int:
         return random.randint(0, self._MAX_SERVER_ID - 1)
 
-    def _get_connection_id(self):
+    def _get_connection_id(self) -> int:
         """
         Generate a connection ID.
 
@@ -97,7 +111,7 @@ class MysqlServer:
 
         return connection_id
 
-    async def start_server(self, **kwargs):
+    async def start_server(self, **kwargs: Any) -> None:
         """
         Start an asyncio socket server.
 
@@ -111,7 +125,7 @@ class MysqlServer:
             kw["port"] = 3306
         self._server = await asyncio.start_server(self._client_connected_cb, **kw)
 
-    async def start_unix_server(self, **kwargs):
+    async def start_unix_server(self, **kwargs: Any) -> None:
         """
         Start an asyncio unix socket server.
 
@@ -123,7 +137,7 @@ class MysqlServer:
         kw.update(kwargs)
         self._server = await asyncio.start_unix_server(self._client_connected_cb, **kw)
 
-    async def serve_forever(self, **kwargs):
+    async def serve_forever(self, **kwargs: Any) -> None:
         """
         Start accepting connections until the coroutine is cancelled.
 
@@ -134,9 +148,10 @@ class MysqlServer:
         """
         if not self._server:
             await self.start_server(**kwargs)
+        assert self._server is not None
         await self._server.serve_forever()
 
-    def close(self):
+    def close(self) -> None:
         """
         Stop serving.
 
@@ -146,7 +161,13 @@ class MysqlServer:
         if self._server:
             self._server.close()
 
-    async def wait_closed(self):
+    async def wait_closed(self) -> None:
         """Wait until the `close` method completes."""
         if self._server:
             await self._server.wait_closed()
+
+    def sockets(self) -> Sequence[socket]:
+        """Get sockets the server is listening on."""
+        if self._server:
+            return self._server.sockets
+        return ()
