@@ -1,4 +1,6 @@
+import asyncio
 import struct
+from ssl import SSLContext
 
 from mysql_mimic.errors import MysqlError, ErrorCode
 from mysql_mimic.types import uint_3, uint_1
@@ -10,12 +12,12 @@ class ConnectionClosed(Exception):
 
 
 class MysqlStream:
-    def __init__(self, reader, writer):
+    def __init__(self, reader: asyncio.StreamReader, writer: asyncio.StreamWriter):
         self.reader = reader
         self.writer = writer
         self.seq = seq(256)
 
-    async def read(self):
+    async def read(self) -> bytes:
         data = b""
         while True:
             header = await self.reader.read(4)
@@ -42,7 +44,7 @@ class MysqlStream:
             if payload_length < 0xFFFFFF:
                 return data
 
-    async def write(self, data):
+    async def write(self, data: bytes) -> None:
         while True:
             # Grab first 0xFFFFFF bytes to send
             payload = data[:0xFFFFFF]
@@ -58,5 +60,20 @@ class MysqlStream:
             if len(payload) != 0xFFFFFF:
                 return
 
-    def reset_seq(self):
+    def reset_seq(self) -> None:
         self.seq.reset()
+
+    async def start_tls(self, ssl: SSLContext) -> None:
+        transport = self.writer.transport
+        protocol = transport.get_protocol()
+        loop = asyncio.get_event_loop()
+        new_transport = await loop.start_tls(
+            transport=transport,
+            protocol=protocol,
+            sslcontext=ssl,
+            server_side=True,
+        )
+
+        # This seems to be the easiest way to wrap the socket created by asyncio
+        self.writer._transport = new_transport  # type: ignore # pylint: disable=protected-access
+        self.reader._transport = new_transport  # type: ignore # pylint: disable=protected-access
