@@ -1,9 +1,9 @@
 """mysql-mimic version information"""
 
-__version__ = "1.0.2"
+__version__ = "1.1.2"
 
 
-def main(name):
+def main(name: str) -> None:
     if name == "__main__":
         print(__version__)
 
